- Added experimental hackish tunneling-over-TCP support.
[tinc] / src / net.h
index 35b500f..40bc934 100644 (file)
--- a/src/net.h
+++ b/src/net.h
@@ -16,7 +16,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-    $Id: net.h,v 1.9.4.3 2000/06/25 15:22:16 guus Exp $
+    $Id: net.h,v 1.9.4.7 2000/08/07 14:52:15 guus Exp $
 */
 
 #ifndef __TINC_NET_H__
@@ -50,6 +50,7 @@
 /* flags */
 #define INDIRECTDATA        0x0001 /* Used to indicate that this host has to be reached indirect */
 #define EXPORTINDIRECTDATA  0x0002 /* Used to indicate uplink that it has to tell others to do INDIRECTDATA */
+#define TCPONLY             0x0004 /* Tells sender to send packets over TCP instead of UDP (for firewalls) */
 
 typedef unsigned long ip_t;
 typedef short length_t;
@@ -82,7 +83,7 @@ typedef struct status_bits_t {
   int validkey:1;                  /* 1 if we currently have a valid key for him */
   int waitingforkey:1;             /* 1 if we already sent out a request */
   int dataopen:1;                  /* 1 if we have a valid UDP connection open */
-  int unused:22;
+  int unused:21;
 } status_bits_t;
 
 typedef struct queue_element_t {
@@ -106,7 +107,8 @@ typedef struct conn_list_t {
   ip_t vpn_ip;                     /* his vpn ip */
   ip_t vpn_mask;                   /* his vpn network address */
   ip_t real_ip;                    /* his real (internet) ip */
-/*  char *hostname;                  /* the hostname of its real ip */
+  char *real_hostname;             /* the hostname of its real ip */
+  char *vpn_hostname;              /* the hostname of the vpn ip */
   short unsigned int port;         /* his portnumber */
   int flags;                       /* his flags */
   int socket;                      /* our udp vpn socket */